package App::IndonesianFinanceUtils;

our $DATE = '2021-02-01'; # DATE
our $VERSION = '0.080'; # VERSION

1;
# ABSTRACT: CLIs related to Indonesian finance

__END__

=pod

=encoding UTF-8

=head1 NAME

App::IndonesianFinanceUtils - CLIs related to Indonesian finance

=head1 VERSION

This document describes version 0.080 of App::IndonesianFinanceUtils (from Perl distribution App-IndonesianFinanceUtils), released on 2021-02-01.

=head1

This distribution contains several CLI's related to Indonesian finance:

=over

=item * L<convert-currency-using-bca>

=item * L<convert-currency-using-gmc>

=item * L<get-jisdor-rates>

=item * L<get-ksei-sec-ownership-url>

=item * L<get-usd-idr-rate-from-bca>

=item * L<get-usd-idr-rate-from-gmc>

=item * L<list-currency-exchange-rates-from-bca>

=item * L<list-currency-exchange-rates-from-gmc>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-IndonesianFinanceUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-IndonesianFinanceUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-App-IndonesianFinanceUtils/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<App::IndonesianBankingUtils>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021, 2016, 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
